@@ -9,6 +9,7 @@ __all__ = ["NewsManager", "NewsItem", "DisplayRestriction",
 	"DisplayInstalledRestriction",
 	"count_unread_news", "display_news_notifications"]
 
+import fnmatch
 import io
 import logging
 import os as _os
@@ -245,8 +246,7 @@ class NewsItem(object):
 		for values in self.restrictions.values():
 			any_match = False
 			for restriction in values:
-				if restriction.checkRestriction(
-					**portage._native_kwargs(kwargs)):
+				if restriction.checkRestriction(**kwargs):
 					any_match = True
 			if not any_match:
 				all_match = False
@@ -270,7 +270,8 @@ class NewsItem(object):
 			# Optimization to ignore regex matchines on lines that
 			# will never match
 			format_match = _formatRE.match(line)
-			if format_match is not None and format_match.group(1) != '1.0':
+			if (format_match is not None and
+					not fnmatch.fnmatch(format_match.group(1), '1.*')):
 				invalids.append((i + 1, line.rstrip('\n')))
 				break
 			if not line.startswith('D'):
